-- 跨服时空
Lua_CrossServerWindow = class("Lua_CrossServerWindow", Lua_Window);
function Lua_CrossServerWindow:ctor()
	self:superCall("ctor");

	self.windowName = "Lua_CrossServerWindow";
	self.skinName = "CrossServerWindow_skin";
	self.layer = MainWinDefine.MAIN_WINDOW_LAYER;
	self.isFullSizeWin = true;
	self.showWinBg = true;
	self.winBgPath = "/images/crossServer/xui_kfsk_bg_1.jpg";

	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_CrossServerWindow:buildPanel(go)
	self:superCall("buildPanel", go);

	self:addLuaEvent("SELECT_CROSS_ITEM", self, self.updateCrossItemInfo);
	self:addLuaEvent("CROSS_SERVER_INFO", self, self.updateCrossShowInfo);
end

function Lua_CrossServerWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.showTipsDes = "";
	self.winBg.anchorValue = 4;
	self.winBg.pivotValue = 4;
	self.winBg:setLocation(0, 0 + GlobalVar.screenOffsetTopH, 0);
	self.titleTxt:setLangValue(202608);

	self.showEff = UICreate.createUIEffect(self.content, "/effects/uiEffects/ui_kfsk_cj", "ui_kfsk_cj", -2, 13 + GlobalVar.screenOffsetTopH);
	-- self.showEff.anchorValue = 1;

	self.rewardList = Lua_DragList.new(self.content, 380, 102, Lua_AxisDefine.Horizontal);
	self.rewardList:setListCell(Lua_CrossServerRewardCell, 115, 102, 1);
	self.rewardList:setRectAnchor(7);
	self.rewardList:setLocation(-52, 442);
	self.rewardList:setScale(0.82, 0.82);

	self.btnList = Lua_DragList.new(self.content,700, 157, Lua_AxisDefine.Horizontal);
	self.btnList:setListCell(Lua_CrossServerCell, 192, 157, 1);
	self.btnList:setRectAnchor(7);
	self.btnList:setLocation(0, 219);

	self.gotoBtn:addClickFuntion(self, self.onGoBtnClick);
	self.detaileBtn:addClickFuntion(self, self.onDetaileBtnClick);
	self.ruleBtn:addClickFuntion(self, self.onRuleBtnClick);

	self:showCrossWinInfo();
end

function Lua_CrossServerWindow:showCrossWinInfo()
	local arr = DataCenter.crossServerUtil.cCrossSeverInfo;
	self.btnList:setArrayData(arr);
	self.btnList:setSelected(1);

	self:updateCrossItemInfo(arr[1])
end

function Lua_CrossServerWindow:updateCrossItemInfo(data)
	self.data = data;
	self.nameTxt.text = data.name;
	self.conditionTxt.text = data.des;

	self.rewardList.canDrag = #data.reward_list > 3;
	self.rewardList:setArrayData(data.reward_list);

	Lua_ProxyManager.getProxy("Lua_CrossServerProxy"):sCrossServerInfo(data.id);
end

function Lua_CrossServerWindow:updateCrossShowInfo()
	if self.data.isOpened then
		self.showTipsDes = LanUtil.getValue(202602);
	else
		self.showTipsDes = DataCenter.crossServerData:openedDes(self.data.func_open_id);
	end
	self.openDesTxt.text = self.showTipsDes;
end

-- 前往
function Lua_CrossServerWindow:onGoBtnClick()
	if self.data.isOpened then
		DataCenter.funcPathUtil:gotoFunction(self.data.func_path_id)
	else
		OperateAlert.show(self.showTipsDes);
	end
end

-- 跨服详情
function Lua_CrossServerWindow:onDetaileBtnClick()
	Lua_WindowUtil.openWin("Lua_CrossServerTipsWindow", Lua_WinParam.ACTION_OPEN);
end

-- 帮助
function Lua_CrossServerWindow:onRuleBtnClick()
	local tipsData = { des = LanUtil.getValue(202607), posX = 145, posY = -250 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_CrossServerWindow:dispose()
	if self.showEff ~= nil then
		self.showEff:dispose();
		self.showEff = nil;
	end
	if self.rewardList ~= nil then
		self.rewardList:dispose();
		self.rewardList = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	self.data = nil;
	
	self:superCall("dispose");
end










Lua_CrossServerRewardCell = class("Lua_CrossServerRewardCell", Lua_ItemIconCell);
function Lua_CrossServerRewardCell:ctor(p)
	self:superCall("ctor", p);
end

function Lua_CrossServerRewardCell:buildShowItem()
	self:superCall("buildShowItem");
	self.itemIcon:setScale(0.82, 0.82);
end

function Lua_CrossServerRewardCell:setData(data)
	self:superCall("setData", data);
	self.itemIcon:showNum(0);
end










Lua_CrossServerCell = class("Lua_CrossServerCell", Lua_ListCell);
function Lua_CrossServerCell:ctor(p)
	self:superCall("ctor", p, "CrossServerCell_skin");
end

function Lua_CrossServerCell:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_CrossServerCell:setData(data)
	self.data = data;
	if data == nil then
		return;
	end

	local spriteName = data.isOpened and "xui_kfsk_scrollbar_1_f" or "xui_kfsk_scrollbar_1_b";
	self.barIcon:setAltas("cross_server_altas", spriteName);
	self.icon:setAltas(data.atlas, data.sprite);
	self.icon:setGray(not data.isOpened);
	self.nameTxt.text = data.name;
end

function Lua_CrossServerCell:onPressClick()
	Lua_MsgUtil.callFunc("SELECT_CROSS_ITEM", self.data);
	return true;
end

function Lua_CrossServerCell:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);

	self.selectIcon:setEnable(bSelect);
end

function Lua_CrossServerCell:dispose()
	self.data = nil;
	self:superCall("dispose");
end